==> ejc-credentials-impl-3.0.0-20220608.025626-40-sources.jar: com/ejianc/certify/vo/CertifyTransferVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 证照调动单
 *
 * @author generator
 */
public class CertifyTransferVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long pkCertifreg; // 证照登记单主键
    private String pkGroup; // 集团
    private Long pkOrg; // 原管理组织
    private Long pkManagedept; // 原管理部门
    private Long pkDrorg; // 调入管理组织
    private Long pkDrdept; // 调入管理部门
    private String dbilldate; // 单据日期
    private String vbillcode; // 单据编码
    private Long pkCertiftype; // 证照名称（选择证照登记单带出）
    private String certifcode; // 证书编号（选择证照登记单带出）
    private String zjCode; // 证件编码（选择证照登记单带出）
    private Long pkCertpsn; // 持证人员
    private String cardId; // 身份证号码
    private String psnPhone; // 电话号码
    private String certStatus; // 证照状态（0-未生效 1-生效 2-失效）
    private String pkBilltype; // 单据类型
    private String vmemo; // 备注
    private String vbusitype; // 业务类型
    private Long applyer; // 调出发起人
    private Long applyerorg; // 调出发起人组织
    private String approver; // 审批人
    private String taudittime; // 审批时间
    private String vapprovenote; // 审批附言
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 
    private String yjIsrecevie; // 调入组织是否收到原件
    private Date ts; // 时间戳
    private Integer billState; // 单据状态


    //excel冗余字段
    private String pkCertpsnName;//持证人员姓名
    private String pkOrgName;//原管理组织名称
    private String pkManagedeptName;//原管理部门名称
    private String pkDrorgName;//调入管理组织名称
    private String pkDrdeptName;//调入管理部门名称
    private String pkCertiftypeName;//证照名称
    private String applyerName;//调出发起人姓名
    private String applyerorgName;//调出发起人组织名称
    private String certStatusName; // 证照状态名称
    private String billStateName; //单据状态名称

    @ReferSerialTransfer(referCode="certifyregH")
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    @ReferDeserialTransfer
    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkOrg() {
        return pkOrg;
    }

    @ReferDeserialTransfer
    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkManagedept() {
        return pkManagedept;
    }

    @ReferDeserialTransfer
    public void setPkManagedept(Long pkManagedept) {
        this.pkManagedept = pkManagedept;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDrorg() {
        return pkDrorg;
    }

    @ReferDeserialTransfer
    public void setPkDrorg(Long pkDrorg) {
        this.pkDrorg = pkDrorg;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDrdept() {
        return pkDrdept;
    }

    @ReferDeserialTransfer
    public void setPkDrdept(Long pkDrdept) {
        this.pkDrdept = pkDrdept;
    }

    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }

    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }

    @ReferSerialTransfer(referCode="certifType")
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    @ReferDeserialTransfer
    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }

    public String getZjCode() {
        return zjCode;
    }

    public void setZjCode(String zjCode) {
        this.zjCode = zjCode;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    @ReferDeserialTransfer
    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }

    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }

    public String getPsnPhone() {
        return psnPhone;
    }

    public void setPsnPhone(String psnPhone) {
        this.psnPhone = psnPhone;
    }

    public String getCertStatus() {
        return certStatus;
    }

    public void setCertStatus(String certStatus) {
        this.certStatus = certStatus;
    }

    public String getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(String pkBilltype) {
        this.pkBilltype = pkBilltype;
    }

    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getApplyer() {
        return applyer;
    }

    @ReferDeserialTransfer
    public void setApplyer(Long applyer) {
        this.applyer = applyer;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getApplyerorg() {
        return applyerorg;
    }

    @ReferDeserialTransfer
    public void setApplyerorg(Long applyerorg) {
        this.applyerorg = applyerorg;
    }

    public String getApprover() {
        return approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }

    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }

    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }

    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }

    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }

    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }

    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }

    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }

    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }

    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }

    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }

    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

    public String getYjIsrecevie() {
        return yjIsrecevie;
    }

    public void setYjIsrecevie(String yjIsrecevie) {
        this.yjIsrecevie = yjIsrecevie;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public String getPkCertpsnName() {
        return pkCertpsnName;
    }

    public void setPkCertpsnName(String pkCertpsnName) {
        this.pkCertpsnName = pkCertpsnName;
    }

    public String getPkOrgName() {
        return pkOrgName;
    }

    public void setPkOrgName(String pkOrgName) {
        this.pkOrgName = pkOrgName;
    }

    public String getPkManagedeptName() {
        return pkManagedeptName;
    }

    public void setPkManagedeptName(String pkManagedeptName) {
        this.pkManagedeptName = pkManagedeptName;
    }

    public String getPkDrorgName() {
        return pkDrorgName;
    }

    public void setPkDrorgName(String pkDrorgName) {
        this.pkDrorgName = pkDrorgName;
    }

    public String getPkDrdeptName() {
        return pkDrdeptName;
    }

    public void setPkDrdeptName(String pkDrdeptName) {
        this.pkDrdeptName = pkDrdeptName;
    }

    public String getPkCertiftypeName() {
        return pkCertiftypeName;
    }

    public void setPkCertiftypeName(String pkCertiftypeName) {
        this.pkCertiftypeName = pkCertiftypeName;
    }

    public String getApplyerName() {
        return applyerName;
    }

    public void setApplyerName(String applyerName) {
        this.applyerName = applyerName;
    }

    public String getApplyerorgName() {
        return applyerorgName;
    }

    public void setApplyerorgName(String applyerorgName) {
        this.applyerorgName = applyerorgName;
    }

    public String getCertStatusName() {
        return certStatusName;
    }

    public void setCertStatusName(String certStatusName) {
        this.certStatusName = certStatusName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
}

==> ejc-credentials-impl-3.0.0-20220616.071707-59-sources.jar: com/ejianc/certify/vo/CertifyTransferVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 证照调动单
 *
 * @author generator
 */
public class CertifyTransferVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private String name; // 调动单名称
    private Long pkCertifreg; // 证照登记单主键
    private String pkGroup; // 集团
    private Long pkOrg; // 原管理组织
    private Long pkManagedept; // 原管理部门
    private Long pkDrorg; // 调入管理组织
    private Long pkDrdept; // 调入管理部门
    private String dbilldate; // 单据日期
    private String vbillcode; // 单据编码
    private Long pkCertiftype; // 证照名称（选择证照登记单带出）
    private String certifcode; // 证书编号（选择证照登记单带出）
    private String zjCode; // 证件编码（选择证照登记单带出）
    private Long pkCertpsn; // 持证人员
    private String cardId; // 身份证号码
    private String psnPhone; // 电话号码
    private String certStatus; // 证照状态（0-未生效 1-生效 2-失效）
    private String pkBilltype; // 单据类型
    private String vmemo; // 备注
    private String vbusitype; // 业务类型
    private Long applyer; // 调出发起人
    private Long applyerorg; // 调出发起人组织
    private String approver; // 审批人
    private String taudittime; // 审批时间
    private String vapprovenote; // 审批附言
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 
    private String yjIsrecevie; // 调入组织是否收到原件
    private Date ts; // 时间戳
    private Integer billState; // 单据状态


    //excel冗余字段
    private String pkCertpsnName;//持证人员姓名
    private String pkOrgName;//原管理组织名称
    private String pkManagedeptName;//原管理部门名称
    private String pkDrorgName;//调入管理组织名称
    private String pkDrdeptName;//调入管理部门名称
    private String pkCertiftypeName;//证照名称
    private String applyerName;//调出发起人姓名
    private String applyerorgName;//调出发起人组织名称
    private String certStatusName; // 证照状态名称
    private String billStateName; //单据状态名称

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @ReferSerialTransfer(referCode = "certifyregH")
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    @ReferDeserialTransfer
    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }

    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkOrg() {
        return pkOrg;
    }

    @ReferDeserialTransfer
    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkManagedept() {
        return pkManagedept;
    }

    @ReferDeserialTransfer
    public void setPkManagedept(Long pkManagedept) {
        this.pkManagedept = pkManagedept;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDrorg() {
        return pkDrorg;
    }

    @ReferDeserialTransfer
    public void setPkDrorg(Long pkDrorg) {
        this.pkDrorg = pkDrorg;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDrdept() {
        return pkDrdept;
    }

    @ReferDeserialTransfer
    public void setPkDrdept(Long pkDrdept) {
        this.pkDrdept = pkDrdept;
    }

    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }

    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }

    @ReferSerialTransfer(referCode = "certifType")
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    @ReferDeserialTransfer
    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    public String getCertifcode() {
        return certifcode;
    }

    public void setCertifcode(String certifcode) {
        this.certifcode = certifcode;
    }

    public String getZjCode() {
        return zjCode;
    }

    public void setZjCode(String zjCode) {
        this.zjCode = zjCode;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkCertpsn() {
        return pkCertpsn;
    }

    @ReferDeserialTransfer
    public void setPkCertpsn(Long pkCertpsn) {
        this.pkCertpsn = pkCertpsn;
    }

    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }

    public String getPsnPhone() {
        return psnPhone;
    }

    public void setPsnPhone(String psnPhone) {
        this.psnPhone = psnPhone;
    }

    public String getCertStatus() {
        return certStatus;
    }

    public void setCertStatus(String certStatus) {
        this.certStatus = certStatus;
    }

    public String getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(String pkBilltype) {
        this.pkBilltype = pkBilltype;
    }

    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getApplyer() {
        return applyer;
    }

    @ReferDeserialTransfer
    public void setApplyer(Long applyer) {
        this.applyer = applyer;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getApplyerorg() {
        return applyerorg;
    }

    @ReferDeserialTransfer
    public void setApplyerorg(Long applyerorg) {
        this.applyerorg = applyerorg;
    }

    public String getApprover() {
        return approver;
    }

    public void setApprover(String approver) {
        this.approver = approver;
    }

    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }

    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }

    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }

    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }

    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }

    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }

    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }

    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }

    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }

    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }

    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

    public String getYjIsrecevie() {
        return yjIsrecevie;
    }

    public void setYjIsrecevie(String yjIsrecevie) {
        this.yjIsrecevie = yjIsrecevie;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public String getPkCertpsnName() {
        return pkCertpsnName;
    }

    public void setPkCertpsnName(String pkCertpsnName) {
        this.pkCertpsnName = pkCertpsnName;
    }

    public String getPkOrgName() {
        return pkOrgName;
    }

    public void setPkOrgName(String pkOrgName) {
        this.pkOrgName = pkOrgName;
    }

    public String getPkManagedeptName() {
        return pkManagedeptName;
    }

    public void setPkManagedeptName(String pkManagedeptName) {
        this.pkManagedeptName = pkManagedeptName;
    }

    public String getPkDrorgName() {
        return pkDrorgName;
    }

    public void setPkDrorgName(String pkDrorgName) {
        this.pkDrorgName = pkDrorgName;
    }

    public String getPkDrdeptName() {
        return pkDrdeptName;
    }

    public void setPkDrdeptName(String pkDrdeptName) {
        this.pkDrdeptName = pkDrdeptName;
    }

    public String getPkCertiftypeName() {
        return pkCertiftypeName;
    }

    public void setPkCertiftypeName(String pkCertiftypeName) {
        this.pkCertiftypeName = pkCertiftypeName;
    }

    public String getApplyerName() {
        return applyerName;
    }

    public void setApplyerName(String applyerName) {
        this.applyerName = applyerName;
    }

    public String getApplyerorgName() {
        return applyerorgName;
    }

    public void setApplyerorgName(String applyerorgName) {
        this.applyerorgName = applyerorgName;
    }

    public String getCertStatusName() {
        return certStatusName;
    }

    public void setCertStatusName(String certStatusName) {
        this.certStatusName = certStatusName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
}
